#ifndef NT2_INCLUDE_CONSTANTS_MINEXPONENT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MINEXPONENT_HPP_INCLUDED

#include <nt2/constant/include/constants/minexponent.hpp>

#endif
